package ocsigen-toolkit

  1. Overview
  2. Docs

Ocsigen Toolkit

Ocsigen Toolkit is a set of reusable user-interface widgets for Eliom applications. The widgets can be produced on the server or on the client from the same code, which makes them particularly suited to mobile, client-server applications.

Ocsigen Toolkit is part of the Ocsigen project.

Documentation

  • Introduction — installation, programming style and an overview of the available widgets.
  • The server and client API of every widget (use the Server API / Client API switch to move between the two sides).

Installation

Ocsigen Toolkit is available via OPAM:

opam install ocsigen-toolkit