popup ?a ?enable_scrolling_hack ?close_button ?confirmation_onclose ?onclose gen_content Display a modal popup. Returns the popup container, in case you need it.
enable_scrolling_hack (default: true) toggle the hack setting popup background (body) to fixed when popups open
Use close_button if you want to add a button to close the popup.
confirmation_on_close is used to ask confirmation to the user when closing the popup with the close button. Only relevant if one of close_button, close_on_background_click, close_on_escape is supplied.
onclose is a hook called just after the popup has been actually closed.
gen_content is a function taking the function closing the popup as parameter, and returning the popup content.
If close_on_background_click (default: false) is true then clicking on the background of the popup closes it.
If close_on_escape (default: true if close_button is supplied) then hitting the escape key will close the popup.